Documentation
¶
Index ¶
- func AddFields(ctx context.Context, fields ...zapcore.Field)
- func Debug(ctx context.Context, msg string, fields ...zap.Field)
- func Error(ctx context.Context, msg string, fields ...zap.Field)
- func Extract(ctx context.Context) *zap.Logger
- func Info(ctx context.Context, msg string, fields ...zap.Field)
- func ToContext(ctx context.Context, logger *zap.Logger) context.Context
- func Warn(ctx context.Context, msg string, fields ...zap.Field)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Debug ¶
Debug is equivalent to calling Debug on the zap.Logger in the context. It is a no-op if the context does not contain a zap.Logger.
func Error ¶
Error is equivalent to calling Error on the zap.Logger in the context. It is a no-op if the context does not contain a zap.Logger.
func Info ¶
Info is equivalent to calling Info on the zap.Logger in the context. It is a no-op if the context does not contain a zap.Logger.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.